@@ -1,16 +1,19 @@
 from typing import List, Sequence
 
+from tealprint import TealPrint
+
 from ...config import config
 from ...core.entities.mod import Mod, ModArg
 from ...core.entities.version_info import VersionInfo
-from ...utils.logger import LogColors, Logger
+from ...gateways.api.mod_finder import ModFinder
+from ...utils.log_colors import LogColors
 from ..download.download import Download
 from .update_repo import UpdateRepo
 
 
 class Update(Download):
-    def __init__(self, repo: UpdateRepo) -> None:
-        super().__init__(repo)
+    def __init__(self, repo: UpdateRepo, finder: ModFinder) -> None:
+        super().__init__(repo, finder)
         self._update_repo = repo
 
     def execute(self, mods: Sequence[ModArg]) -> None:
@@ -27,20 +30,19 @@ class Update(Download):
 
         self.find_download_and_install(mods_to_update)
 
-    def on_version_found(self, old: Mod, new: Mod) -> None:
+    def on_new_version_downloaded(self, old: Mod, new: Mod) -> None:
         if new.file:
             if Update._has_downloaded_new_file(old, new):
                 if not config.pretend and old.file:
                     self._update_repo.remove_mod_file(old.file)
 
-                Logger.info(
-                    f"🟢 Updated {old.version} -> {new.version}",
-                    LogColors.green,
-                    indent=1,
-                )
+                TealPrint.info(f"🟢 Updated {old.version} -> {new.version}", color=LogColors.updated)
+
+    def on_no_change(self, mod: Mod) -> None:
+        TealPrint.verbose("🔵 Already up-to-date")
 
     def on_version_not_found(self, mod: Mod, versions: List[VersionInfo]) -> None:
-        Logger.verbose("🟨 No new version found", LogColors.skip, indent=1)
+        TealPrint.verbose("🟨 No new version found", color=LogColors.skip)
 
     @staticmethod
     def _has_downloaded_new_file(old: Mod, new: Mod) -> bool:
