@@ -1,5 +1,5 @@
 from enum import Enum
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Set
 
 from tealprint import TealPrint
 
@@ -69,14 +69,14 @@ class ModrinthApi(Api):
     def _search_mod(self, search: str) -> List[Mod]:
         mods: List[Mod] = []
         json = self.http.get(ModrinthApi._make_search_url(search))
-
-        for mod_info in json["hits"]:
-            if {"slug", "mod_id", "title"}.issubset(mod_info):
-                slug = mod_info["slug"]
-                site_id = str(mod_info["mod_id"])
-                site_id = site_id.replace("local-", "")
-                name = mod_info["title"]
-                mods.append(Mod(id="", name=name, sites={Sites.modrinth: Site(Sites.modrinth, site_id, slug)}))
+        if "hits" in json:
+            for mod_info in json["hits"]:
+                if {"slug", "mod_id", "title"}.issubset(mod_info):
+                    slug = mod_info["slug"]
+                    site_id = str(mod_info["mod_id"])
+                    site_id = site_id.replace("local-", "")
+                    name = mod_info["title"]
+                    mods.append(Mod(id="", name=name, sites={Sites.modrinth: Site(Sites.modrinth, site_id, slug)}))
 
         return mods
 
@@ -104,7 +104,7 @@ class ModrinthApi(Api):
     def _json_to_version_info(data: Any) -> VersionInfo:
         return VersionInfo(
             stability=Stabilities.from_name(data["version_type"]),
-            mod_loaders=Api._to_mod_loaders(data["loaders"]),
+            mod_loaders=ModrinthApi._to_mod_loaders(data["loaders"]),
             site=Sites.modrinth,
             upload_time=Api._to_epoch_time(data["date_published"]),
             minecraft_versions=data["game_versions"],
@@ -145,3 +145,12 @@ class ModrinthApi(Api):
         if json and "mod_id" in json:
             return str(json["mod_id"])
         return ""
+
+    @staticmethod
+    def _to_mod_loaders(loaders: List[str]) -> Set[ModLoaders]:
+        mod_loaders: Set[ModLoaders] = set()
+
+        for loader in loaders:
+            mod_loaders.add(ModLoaders.from_name(loader))
+
+        return mod_loaders
